==> tryton-client_6.0.10.orig.tar.gz: tryton-6.0.10/tryton/common/__init__.py <==
# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from .common import (
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, check_version, TRYTON_ICON, setup_window)
from .domain_inversion import (
    domain_inversion, eval_domain, localize_domain, merge, inverse_leaf,
    filter_leaf, prepare_reference_domain, extract_reference_models, concat,
    simplify, unique_value)
from .environment import EvalEnvironment
from . import timedelta

__all__ = [
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, domain_inversion, eval_domain,
    localize_domain, merge, inverse_leaf, filter_leaf,
    prepare_reference_domain, extract_reference_models, concat, simplify,
    unique_value, EvalEnvironment, timedelta, check_version, TRYTON_ICON,
    setup_window]

==> tryton-client_6.0.34.orig.tar.gz: tryton-6.0.34/tryton/common/__init__.py <==
# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from .common import (
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, check_version, TRYTON_ICON, setup_window,
    get_gdk_backend)
from .domain_inversion import (
    domain_inversion, eval_domain, localize_domain, merge, inverse_leaf,
    filter_leaf, prepare_reference_domain, extract_reference_models, concat,
    simplify, unique_value)
from .environment import EvalEnvironment
from . import timedelta

__all__ = [
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, domain_inversion, eval_domain,
    localize_domain, merge, inverse_leaf, filter_leaf,
    prepare_reference_domain, extract_reference_models, concat, simplify,
    unique_value, EvalEnvironment, timedelta, check_version, TRYTON_ICON,
    setup_window, get_gdk_backend]
